//
//  ViewController.swift
//  Video
//
//  Created by Mark Meretzky on 11/20/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit;
import MediaPlayer;	//for MPMoviePlayerController

class ViewController: UIViewController {
	let moviePlayerController: MPMoviePlayerController = MPMoviePlayerController();

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);

		let bundle: NSBundle? = NSBundle.mainBundle();
		if bundle == nil {
			println("Could not access main bundle.");
			return;
		}
		println("bundle.bundlePath = \(bundle!.bundlePath)\n");

		let filename: String? = bundle!.pathForResource("sneeze", ofType: "m4v");
		if filename == nil {
			println("could not find file sneeze.m4v");
			return;
		}
		println("filename = \(filename!)\n");

		let url: NSURL? = NSURL(fileURLWithPath: filename!);
		if url == nil {
			println("could not create URL for file \(filename)");
			return;
		}
		println("url = \(url!)\n");

		moviePlayerController = MPMoviePlayerController(contentURL: url!);
		println("moviePlayerController.contentURL = \(moviePlayerController.contentURL)\n");

		moviePlayerController.shouldAutoplay = false;	//don't start spontaneously
		moviePlayerController.scalingMode = MPMovieScalingMode.None;
		moviePlayerController.controlStyle = MPMovieControlStyle.Fullscreen;
		moviePlayerController.movieSourceType = MPMovieSourceType.File; //vs. stream
		moviePlayerController.prepareToPlay();

		let center: NSNotificationCenter = NSNotificationCenter.defaultCenter();

		center.addObserver(self,
			selector: "playbackDidFinish:",
			name: MPMoviePlayerPlaybackDidFinishNotification,
			object: moviePlayerController);
	}

	override func loadView() {
		//Implant a reference to this view controller into the newborn View.
		view = View(viewController: self);
	}

	override func viewDidLoad() {
		super.viewDidLoad()
		// Do any additional setup after loading the view, typically from a nib.
	}

	//Called when the user presses the button in the View.

	func touchUpInside(button: UIButton!) {
		var title: String? = button.titleForState(UIControlState.Normal);
		if title == nil {
			title = "untitled";
		}
		println("touchUpInside title = \(title!)");

		//Make the moviePlayerController's view the same size
		//as the big white View it's about to cover.
		moviePlayerController.view.frame = view.frame;

		moviePlayerController.view.autoresizingMask =
			UIViewAutoresizing.FlexibleLeftMargin
			| UIViewAutoresizing.FlexibleRightMargin
			| UIViewAutoresizing.FlexibleTopMargin
			| UIViewAutoresizing.FlexibleBottomMargin;

		view.addSubview(moviePlayerController.view);
		moviePlayerController.play();
	}

	//Called when the playback finishes.

	func playbackDidFinish(notification: NSNotification) {
		//If the userInfo dictionary contains either of these two keys,
		//print the corresponding values.
		if notification.userInfo != nil {
			let userInfo:[NSObject: AnyObject] = notification.userInfo!;
			let reason: Int? = userInfo[MPMoviePlayerPlaybackDidFinishReasonUserInfoKey] as? Int;
			if reason != nil && reason! != MPMovieFinishReason.PlaybackEnded.rawValue {
				println("playbackDidFinish: reason = \(reason!)");
			}
			let error: NSError? = userInfo["error"] as? NSError;
			if error != nil {
				println("playbackDidFinish: error =  \(error!)");
			}
		}

		//Remove the moviePlayerController's view from the big white View.
		moviePlayerController.view.removeFromSuperview();

		moviePlayerController.prepareToPlay();
	}

	override func supportedInterfaceOrientations() -> Int {
		return Int(UIInterfaceOrientationMask.LandscapeLeft.rawValue);
	}

	override func didReceiveMemoryWarning() {
		super.didReceiveMemoryWarning()
		// Dispose of any resources that can be recreated.
	}


}

